@@ -41,6 +41,8 @@
 
 #define KNOTIFICATIONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KNOTIFICATIONS_NO_DEPRECATED) && !defined(KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNOTIFICATIONS_NO_DEPRECATED
-#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57100
+#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
 #endif
 #ifdef KNOTIFICATIONS_NO_DEPRECATED_WARNINGS
 #  define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x57100
+#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x54300
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KNOTIFICATIONS_DEPRECATED
-#  define KNOTIFICATIONS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KNOTIFICATIONS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KNOTIFICATIONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -113,33 +115,7 @@
 #else
 #  define KNOTIFICATIONS_DEPRECATED_VERSION_5_67(text)
 #endif
-
-#if KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE >= 0x54b00
-#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_75(text) KNOTIFICATIONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_75(text)
-#endif
-
-#if KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
-#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_76(text) KNOTIFICATIONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_76(text)
-#endif
-
-#if KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE >= 0x54f00
-#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_79(text) KNOTIFICATIONS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KNOTIFICATIONS_DEPRECATED_VERSION_5_79(text)
-#endif
 #define KNOTIFICATIONS_DEPRECATED_VERSION_5(minor, text)      KNOTIFICATIONS_DEPRECATED_VERSION_5_##minor(text)
 #define KNOTIFICATIONS_DEPRECATED_VERSION(major, minor, text) KNOTIFICATIONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KNOTIFICATIONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNOTIFICATIONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KNOTIFICATIONS_DEPRECATED_VERSION(major, minor, text)
-#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNOTIFICATIONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KNOTIFICATIONS_EXPORT_H */
